/// <reference types="node" />
import Browser from '../interfaces/browser';
import PNGProcessor from '../interfaces/png-processor';
import Screenshotter, { ScreenshotOptions } from '../interfaces/screenshotter';
import { MugshotSelector } from './mugshot';
export interface BrowserScreenshotterOptions {
    pngProcessor?: PNGProcessor;
    /**
     * Disable any CSS animations that might cause test flakiness.
     */
    disableAnimations?: boolean;
}
/**
 * Take screenshots from a Webdriver compatible browser.
 */
export default class BrowserScreenshotter implements Screenshotter {
    private readonly browser;
    private readonly pngProcessor;
    private readonly disableAnimations;
    constructor(browser: Browser, { pngProcessor, disableAnimations }?: BrowserScreenshotterOptions);
    /**
     * Take screenshots of selectors by first taking a viewport screenshot and
     * then cropping the element out.
     *
     * The element's bounding rectangle will be used to crop it out of the
     * viewport screenshot. If the element is not fully visible in the viewport
     */
    takeScreenshot(selectorOrOptions?: MugshotSelector | ScreenshotOptions, options?: ScreenshotOptions): Promise<Buffer>;
    private crop;
    private ignore;
}
